@@ -84,6 +84,7 @@ my @extra_exports = qw(
   check_compiler
   have_module
   blib_load
+  timed_out
 );
 push @EXPORT, @extra_exports;
 __PACKAGE__->export(scalar caller, @extra_exports);
@@ -93,7 +94,7 @@ __PACKAGE__->export(scalar caller, @extra_exports);
 ########################################################################
 
 # always return to the current directory
-{ 
+{
   my $cwd = File::Spec->rel2abs(Cwd::cwd);
 
   sub original_cwd { return $cwd }
@@ -188,7 +189,6 @@ sub find_in_path {
   return;
 }
 
-# returns ($have_c_compiler, $C_support_feature);
 sub check_compiler {
   return (1,1) if $ENV{PERL_CORE};
 
@@ -214,7 +214,7 @@ sub check_compiler {
     );
     $tmp_exec = 0 == system( $exe );
   }
-  return ($have_c_compiler, $mb->feature('C_support'), $tmp_exec);
+  return ($have_c_compiler, $tmp_exec);
 }
 
 sub have_module {
@@ -239,5 +239,23 @@ sub blib_load {
   }
 }
 
+sub timed_out {
+  my ($sub, $timeout) = @_;
+  return unless $sub;
+  $timeout ||= 60;
+
+  my $saw_alarm = 0;
+  eval {
+    local $SIG{ALRM} = sub { $saw_alarm++; die "alarm\n"; }; # NB: \n required
+    alarm $timeout;
+    $sub->();
+    alarm 0;
+  };
+  if ($@) {
+    die unless $@ eq "alarm\n";   # propagate unexpected errors
+  }
+  return $saw_alarm;
+}
+
 1;
 # vim:ts=2:sw=2:et:sta
